==> PyAlgoTrade-0.13.tar.gz: PyAlgoTrade-0.13/pyalgotrade/dataseries/bards.py <==
# PyAlgoTrade
# 
# Copyright 2013 Gabriel Martin Becedillas Ruiz
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
"""

from pyalgotrade import dataseries

class BarDataSeries(dataseries.SequenceDataSeries):
	"""A :class:`pyalgotrade.dataseries.DataSeries` of :class:`pyalgotrade.bar.Bar` instances.

	:param maxLen: The maximum number of values to hold. If not None, it must be greater than 0.
		Once a bounded length is full, when new items are added, a corresponding number of items are discarded from the opposite end.
	:type maxLen: int.
	"""

	def __init__(self, maxLen=dataseries.DEFAULT_MAX_LEN):
		dataseries.SequenceDataSeries.__init__(self, maxLen)
		self.__openDS = dataseries.SequenceDataSeries(maxLen)
		self.__closeDS = dataseries.SequenceDataSeries(maxLen)
		self.__highDS = dataseries.SequenceDataSeries(maxLen)
		self.__lowDS = dataseries.SequenceDataSeries(maxLen)
		self.__volumeDS = dataseries.SequenceDataSeries(maxLen)
		self.__adjCloseDS = dataseries.SequenceDataSeries(maxLen)

	def append(self, value):
		self.appendWithDateTime(value.getDateTime(), value)

	def appendWithDateTime(self, dateTime, value):
		assert(dateTime != None)
		assert(value != None)
		dataseries.SequenceDataSeries.appendWithDateTime(self, dateTime, value)
		self.__openDS.appendWithDateTime(dateTime, value.getOpen())
		self.__closeDS.appendWithDateTime(dateTime, value.getClose())
		self.__highDS.appendWithDateTime(dateTime, value.getHigh())
		self.__lowDS.appendWithDateTime(dateTime, value.getLow())
		self.__volumeDS.appendWithDateTime(dateTime, value.getVolume())
		self.__adjCloseDS.appendWithDateTime(dateTime, value.getAdjClose())

	def getOpenDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the open prices."""
		return self.__openDS

	def getCloseDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the close prices."""
		return self.__closeDS

	def getHighDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the high prices."""
		return self.__highDS

	def getLowDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the low prices."""
		return self.__lowDS

	def getVolumeDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the volume."""
		return self.__volumeDS

	def getAdjCloseDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the adjusted close prices."""
		return self.__adjCloseDS

==> PyAlgoTrade-0.14.tar.gz: PyAlgoTrade-0.14/pyalgotrade/dataseries/bards.py <==
# PyAlgoTrade
# 
# Copyright 2013 Gabriel Martin Becedillas Ruiz
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#   http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
.. moduleauthor:: Gabriel Martin Becedillas Ruiz <gabriel.becedillas@gmail.com>
"""

from pyalgotrade import dataseries

class BarDataSeries(dataseries.SequenceDataSeries):
	"""A DataSeries of :class:`pyalgotrade.bar.Bar` instances.

	:param maxLen: The maximum number of values to hold. If not None, it must be greater than 0.
		Once a bounded length is full, when new items are added, a corresponding number of items are discarded from the opposite end.
	:type maxLen: int.
	"""

	def __init__(self, maxLen=dataseries.DEFAULT_MAX_LEN):
		dataseries.SequenceDataSeries.__init__(self, maxLen)
		self.__openDS = dataseries.SequenceDataSeries(maxLen)
		self.__closeDS = dataseries.SequenceDataSeries(maxLen)
		self.__highDS = dataseries.SequenceDataSeries(maxLen)
		self.__lowDS = dataseries.SequenceDataSeries(maxLen)
		self.__volumeDS = dataseries.SequenceDataSeries(maxLen)
		self.__adjCloseDS = dataseries.SequenceDataSeries(maxLen)

	def append(self, value):
		self.appendWithDateTime(value.getDateTime(), value)

	def appendWithDateTime(self, dateTime, value):
		assert(dateTime != None)
		assert(value != None)
		dataseries.SequenceDataSeries.appendWithDateTime(self, dateTime, value)
		self.__openDS.appendWithDateTime(dateTime, value.getOpen())
		self.__closeDS.appendWithDateTime(dateTime, value.getClose())
		self.__highDS.appendWithDateTime(dateTime, value.getHigh())
		self.__lowDS.appendWithDateTime(dateTime, value.getLow())
		self.__volumeDS.appendWithDateTime(dateTime, value.getVolume())
		self.__adjCloseDS.appendWithDateTime(dateTime, value.getAdjClose())

	def getOpenDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the open prices."""
		return self.__openDS

	def getCloseDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the close prices."""
		return self.__closeDS

	def getHighDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the high prices."""
		return self.__highDS

	def getLowDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the low prices."""
		return self.__lowDS

	def getVolumeDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the volume."""
		return self.__volumeDS

	def getAdjCloseDataSeries(self):
		"""Returns a :class:`pyalgotrade.dataseries.DataSeries` with the adjusted close prices."""
		return self.__adjCloseDS
